@@ -7,14 +7,21 @@ from featuretools.primitives.utils import (
 )
 from .rust_dfs import Primitive, Feature
 import random
+import numpy as np
+from datetime import datetime as dt
+from woodwork.logical_types import Ordinal
 
 
 tag_map = {
     "numeric": "Numeric",
     "category": "Categorical",
+    "categorical": "Categorical",
     "time_index": "TimeIndex",
+    "timeindex": "TimeIndex",
     "foreign_key": "ForeignKey",
+    "foreignkey": "ForeignKey",
     "date_of_birth": "DateOfBirth",
+    "dateofbirth": "DateOfBirth",
     "index": "Index",
 }
 
@@ -55,11 +62,11 @@ def convert_primitives(ft_primitives):
 def dataframe_to_features(df):
     features = []
     for name, col in df.ww.schema.columns.items():
-        col_dict = col_to_dict(col)
+        col_dict = col_to_dict(col, "unknown")
         f = Feature(
             name,
             col_dict["logical_type"],
-            col_dict["semantic_tag"] if col_dict["semantic_tag"] else "Any",
+            col_dict["semantic_tag"],
         )
 
         features.append(f)
@@ -96,9 +103,9 @@ def convert_feature(f_feature, base_features=None):
     r_primitive = convert_primitive(primitive)
 
     if hasattr(f_feature, "return_type"):
-        col_dict = col_to_dict(f_feature.return_type)
+        col_dict = col_to_dict(f_feature.return_type, "unknown")
     else:
-        col_dict = col_to_dict(primitive.return_type)
+        col_dict = col_to_dict(primitive.return_type, "unknown")
 
     return Feature(
         name,
@@ -109,18 +116,21 @@ def convert_feature(f_feature, base_features=None):
     )
 
 
-def col_to_dict(col):
+def col_to_dict(col, unknown_type="any"):
+
     if col.logical_type:
         lt_name = type(col.logical_type).__name__
     else:
-        lt_name = None
+        lt_name = unknown_type
 
     semantic_tags = list(col.semantic_tags)
 
     if len(semantic_tags):
-        semantic_tags = tag_map[semantic_tags[0]]
+        # todo: handle multiple semantic tags
+        semantic_tags = tag_map[semantic_tags[0].lower()]
     else:
-        semantic_tags = None
+        semantic_tags = unknown_type
+
     return {
         "logical_type": lt_name,
         "semantic_tag": semantic_tags,
@@ -163,7 +173,27 @@ def serialize_primitive(primitive, function_type):
     }
 
 
-def generate_fake_dataframe(n_rows=10, col_defs=[("Integer", 2)]):
+logical_type_mapping = {
+    "Boolean": [True, False],
+    "BooleanNullable": [True, False, np.nan],
+    "Datetime": [dt(2020, 1, 1, 12, 0, 0), dt(2020, 6, 1, 12, 0, 0)],
+    "EmailAddress": ["john.smith@example.com", "sally.jonex@example.com"],
+    "LatLong": [(1, 2), (3, 4)],
+    "NaturalLanguage": ["This is sentence 1", "This is sentence 2"],
+    "Ordinal": [1, 2, 3],
+    "URL": ["https://www.example.com", "https://www.example2.com"],
+}
+
+semantic_tag_mapping = {
+    "Categorical": ["A", "B", "C"],
+    "DateOfBirth": [dt(2020, 1, 1, 12, 0, 0), dt(2020, 6, 1, 12, 0, 0)],
+    "ForeignKey": [1, 2],
+    "Numeric": [1.2, 2.3, 3.4],
+    "TimeIndex": [dt(2020, 1, 1, 12, 0, 0), dt(2020, 6, 1, 12, 0, 0)],
+}
+
+
+def generate_fake_dataframe(n_rows=10, col_defs=[("Numeric", 2)], time_index=False):
     def flatten(xss):
         return [x for xs in xss for x in xs]
 
@@ -184,15 +214,56 @@ def generate_fake_dataframe(n_rows=10, col_defs=[("Integer", 2)]):
 
         return pd.DataFrame(data)
 
+    def gen_type_dict(lt, st, start_idx=0, n_features=5):
+        lt_dict = {}
+        st_dict = {}
+        for n in range(n_features):
+            name = f"F_{start_idx + n}"
+            if lt:
+                lt_dict[name] = lt
+            if st:
+                st_dict[name] = st
+        return lt_dict, st_dict
+
     dataframes = [pd.DataFrame({"idx": range(n_rows)})]
 
+    lt_dict = {}
+    st_dict = {}
     starting_col = 0
     for typ, n_cols in col_defs:
-        dataframes.append(gen_dataframe(typ, n_rows, starting_col, n_cols))
+        logical_type = None
+        semantic_tag = None
+        if typ in logical_type_mapping:
+            logical_type = typ
+            values = logical_type_mapping[typ]
+            if logical_type == "Ordinal":
+                logical_type = Ordinal(order=values)
+        elif typ in semantic_tag_mapping:
+            semantic_tag = typ.lower()
+            values = semantic_tag_mapping[typ]
+        else:
+            values = typ
+
+        dataframes.append(gen_dataframe(values, n_rows, starting_col, n_cols))
+        lt_dict_tmp, st_dict_tmp = gen_type_dict(
+            logical_type, semantic_tag, starting_col, n_cols
+        )
+        lt_dict.update(lt_dict_tmp)
+        st_dict.update(st_dict_tmp)
 
         starting_col += n_cols
 
-    return pd.concat(dataframes, axis=1)
+    df = pd.concat(dataframes, axis=1)
+
+    other_kwargs = {}
+    if time_index:
+        df['t_idx'] = pd.date_range(start=dt(2020, 1, 1, 12, 0, 0), periods=n_rows)
+        lt_dict['t_idx'] = 'Datetime'
+        other_kwargs['time_index'] = 't_idx'
+
+    df.ww.init(name="nums", index="idx", logical_types=lt_dict, semantic_tags=st_dict, **other_kwargs)
+
+    return df
 
 
 def df_to_es(df):
@@ -235,9 +306,9 @@ def serialize_all_primitives():
     all_prims = []
 
     for p in trans_prims:
-        all_prims.append(serialize_primitive(p(), "transform"))
+        all_prims.append(serialize_primitive(p(), "transform", "any"))
 
     for p in agg_prims:
-        all_prims.append(serialize_primitive(p(), "aggregation"))
+        all_prims.append(serialize_primitive(p(), "aggregation", "any"))
 
     json.dump(all_prims, open("primitives.json", "w"))
