@@ -1,10 +1,10 @@
 mod arrange_featureset;
 mod generate_combinations;
 mod generate_feature_sets;
-mod generate_features_for_primitives;
+mod generate_features_for_primitive;
 mod index_input_set;
 
 use self::generate_combinations::*;
 pub use self::generate_feature_sets::*;
-pub use self::generate_features_for_primitives::*;
+pub use self::generate_features_for_primitive::*;
 use self::index_input_set::*;
