@@ -1,18 +1,18 @@
+pub mod column_schema;
 pub mod dfs;
 pub mod feature;
 pub mod input_set;
-pub mod input_type;
 pub mod logical_types;
 pub mod primitive;
 
+use column_schema::ColumnSchema;
 use input_set::InputSet;
-use input_type::InputType;
 use rayon::prelude::*;
 
 use feature::{compare_featuresets, generate_fake_features as r_generate_fake_features, Feature};
 use pyo3::prelude::*;
 
-use crate::{dfs::generate_features_for_primitives, primitive::Primitive};
+use crate::{dfs::generate_features_for_primitive, primitive::Primitive};
 
 #[pyfunction]
 fn load_primitives(filename: String) -> PyResult<Vec<Primitive>> {
@@ -38,11 +38,13 @@ fn generate_features(features: Vec<Feature>, primitives: Vec<Primitive>) -> PyRe
     let new_features: Vec<Feature> = t1_primitives
         .par_iter()
         // .iter()
-        .map(|&p| generate_features_for_primitives(p, features_ref))
+        .map(|&p| generate_features_for_primitive(p, features_ref))
         .flatten()
         .collect();
 
-    Ok(new_features)
+    // append new feature to origin features
+    let all_features: Vec<Feature> = features.into_iter().chain(new_features).collect();
+    Ok(all_features)
 }
 
 /// A Python module implemented in Rust.
@@ -55,7 +57,7 @@ fn rust_dfs(_py: Python, m: &PyModule) -> PyResult<()> {
 
     m.add_class::<Feature>()?;
     m.add_class::<Primitive>()?;
-    m.add_class::<InputType>()?;
+    m.add_class::<ColumnSchema>()?;
     m.add_class::<InputSet>()?;
 
     Ok(())
