@@ -14,12 +14,12 @@ pub enum LogicalTypes {
     Integer,
     IntegerNullable,
     PostalCode,
-    Unknown,
     Ordinal,
     EmailAddress,
     LatLong,
     URL,
     NaturalLanguage,
+    Timedelta,
 
     // Semantic Tags
     Numeric,
@@ -28,8 +28,9 @@ pub enum LogicalTypes {
     DateOfBirth,
     Index,
 
-    //Other - Hack
+    //Other - Hack?
     Any,
+    Unknown,
 }
 
 impl TryFrom<&str> for LogicalTypes {
@@ -56,6 +57,7 @@ impl TryFrom<&str> for LogicalTypes {
             "latlong" => Ok(LogicalTypes::LatLong),
             "url" => Ok(LogicalTypes::URL),
             "naturallanguage" => Ok(LogicalTypes::NaturalLanguage),
+            "timedelta" => Ok(LogicalTypes::Timedelta),
 
             // Semantic Tags
             "numeric" => Ok(LogicalTypes::Numeric),
