@@ -4,7 +4,7 @@ use std::fs::read_to_string;
 
 use serde::{Deserialize, Serialize};
 
-use crate::{input_set::InputSet, input_type::InputType};
+use crate::{column_schema::ColumnSchema, input_set::InputSet};
 
 #[pyclass]
 #[derive(Debug, PartialEq, Eq, Deserialize, Serialize, Clone, Hash)]
@@ -13,8 +13,8 @@ pub struct Primitive {
     #[serde(alias = "type")]
     pub name: String,
     pub module: String,
-    pub input_types: Vec<InputSet>,
-    pub return_type: InputType,
+    pub column_schemas: Vec<InputSet>,
+    pub return_type: ColumnSchema,
     pub function_type: String,
     pub commutative: bool,
 }
@@ -27,35 +27,35 @@ impl Primitive {
         module: &str,
         function_type: &str,
         commutative: bool,
-        input_types: Vec<Vec<(Option<&str>, Option<&str>)>>,
+        column_schemas: Vec<Vec<(Option<&str>, Option<&str>)>>,
         return_type: (Option<&str>, Option<&str>),
     ) -> Self {
-        let a = input_types
+        let a = column_schemas
             .iter()
             .map(|x| InputSet::__init__(x.clone()))
             .collect();
 
-        let b = InputType::__init__(return_type.0, return_type.1);
+        let b = ColumnSchema::__init__(return_type.0, return_type.1);
 
         Primitive {
             name: name.to_string(),
             module: module.to_string(),
             function_type: function_type.to_string(),
             commutative,
-            input_types: a,
+            column_schemas: a,
             return_type: b,
         }
     }
     fn __str__(&self) -> PyResult<String> {
         Ok(format!(
             "{}:{}:{}:{}:{:?}",
-            self.name, self.module, self.function_type, self.commutative, self.input_types
+            self.name, self.module, self.function_type, self.commutative, self.column_schemas
         ))
     }
     fn __repr__(&self) -> PyResult<String> {
         Ok(format!(
             "{}:{}:{}:{}:{:?}",
-            self.name, self.module, self.function_type, self.commutative, self.input_types
+            self.name, self.module, self.function_type, self.commutative, self.column_schemas
         ))
     }
 }
@@ -93,14 +93,14 @@ impl fmt::Display for Primitive {
 impl Primitive {
     pub fn new(
         name: String,
-        input_types: Vec<InputSet>,
-        return_type: InputType,
+        column_schemas: Vec<InputSet>,
+        return_type: ColumnSchema,
         commutative: bool,
     ) -> Primitive {
         Primitive {
             name,
             module: "".to_string(),
-            input_types,
+            column_schemas,
             return_type,
             function_type: "transform".to_string(),
             commutative,
@@ -111,18 +111,14 @@ impl Primitive {
 #[macro_export]
 macro_rules! primitive {
     ($name:expr, $inputs:expr, $r_type:expr, $commutative:expr) => {{
-        use crate::primitive::Primitive;
+        use $crate::primitive::Primitive;
         Primitive::new($name.to_string(), $inputs, $r_type, $commutative)
     }};
 }
 #[cfg(test)]
 mod tests {
-    use super::Primitive;
+    use crate::column_schema;
     use crate::input_set;
-    use crate::input_set::InputSet;
-    use crate::input_type;
-    use crate::input_type::InputType;
-    use crate::logical_types::LogicalTypes;
 
     #[test]
     fn test_macro() {
@@ -132,7 +128,7 @@ mod tests {
             input_set![["ordinal", ""], ["ordinal", ""]],
         ];
 
-        let r_type = input_type!["integer", "numeric"];
+        let r_type = column_schema!["integer", "numeric"];
 
         let p = primitive!("GreaterThan", inputs, r_type, false);
         println!("{:?}", p);
@@ -146,7 +142,7 @@ mod tests {
             input_set![["ordinal", ""], ["ordinal", ""]],
         ];
 
-        let r_type1 = input_type!["integer", "numeric"];
+        let r_type1 = column_schema!["integer", "numeric"];
 
         let p1 = primitive!("GreaterThan", inputs1, r_type1, false);
 
@@ -156,7 +152,7 @@ mod tests {
             input_set![["ordinal", ""], ["ordinal", ""]],
         ];
 
-        let r_type2 = input_type!["integer", "numeric"];
+        let r_type2 = column_schema!["integer", "numeric"];
 
         let p2 = primitive!("GreaterThan", inputs2, r_type2, false);
 
